Tools
==================

``piel`` aims to provide an integrated workflow to co-design photonics and electronics. It does not aim to replace the individual functionality of each design tool, but rather provide a glue to easily connect them all together and extract the system performance.


.. toctree::
    :caption: Contents:

    overview
    dependencies/index
    integration/index
